@@ -12,9 +12,9 @@ module SQL
     end
 
     def recreate_database
-      execute "DROP DATABASE #{db_name}"
-      execute "CREATE DATABASE #{db_name}"
-      execute "USE #{db_name}"
+      execute "DROP DATABASE #{schema_name}"
+      execute "CREATE DATABASE #{schema_name}"
+      execute "USE #{schema_name}"
     end
 
     def supports_serial?
@@ -36,7 +36,7 @@ module SQL
     class Table
       def initialize(adapter, table_name)
         @columns = []
-        adapter.query_table(table_name).each do |col_struct|
+        adapter.table_info(table_name).each do |col_struct|
           @columns << SQL::Mysql::Column.new(col_struct)
         end
       end
