@@ -1,33 +1,45 @@
 require 'spec_helper'
 
-ADAPTERS.each do |adapter|
-  describe "Using Adapter #{adapter}, " do
+describe "A Migration" do
+
+  supported_by :postgres, :mysql, :sqlite, :oracle, :sqlserver do
+
     describe DataMapper::Migration, 'interface' do
+
+      before(:all) do
+        @adapter = DataMapper::Spec.adapter
+      end
+
       before do
         @migration = DataMapper::Migration.new(1, :create_people_table, :verbose => false) { }
       end
 
       it "should have a postition attribute" do
         @migration.should respond_to(:position)
-        @migration.should respond_to(:position=)
+
         @migration.position.should == 1
       end
 
       it "should have a name attribute" do
         @migration.should respond_to(:name)
-        @migration.should respond_to(:name=)
+
         @migration.name.should == :create_people_table
       end
 
-      it "should have a :database option" do
-        DataMapper.setup(:other, "sqlite3://#{Dir.pwd}/migration_other.db")
+      it "should have a :repository option" do
+        m = DataMapper::Migration.new(2, :create_dogs_table, :repository => :alternate) {}
 
-        m = DataMapper::Migration.new(2, :create_dogs_table, :database => :other) {}
-        m.instance_variable_get(:@database).name.should == :other
+        m.instance_variable_get(:@repository).should == :alternate
       end
 
-      it "should use the default database by default" do
-        @migration.instance_variable_get(:@database).name.should == :default
+      it "should use the default repository by default" do
+        @migration.instance_variable_get(:@repository).should == :default
+      end
+
+      it "should still support a :database option" do
+        m = DataMapper::Migration.new(2, :create_legacy_table, :database => :legacy) {}
+
+        m.instance_variable_get(:@repository).should == :legacy
       end
 
       it "should have a verbose option" do
@@ -49,15 +61,21 @@ ADAPTERS.each do |adapter|
         [m1, m2, m3, m4].sort.should == [m1, m3, m2, m4]
       end
 
-      expected_module = {
-        :sqlite3  => lambda { SQL::Sqlite3 },
-        :mysql    => lambda { SQL::Mysql },
-        :postgres => lambda { SQL::Postgresql }
-      }[adapter][]
+      adapter = DataMapper::Spec.adapter_name
 
-      it "should extend with #{expected_module} when adapter is #{adapter}" do
-        migration = DataMapper::Migration.new(1, :"#{adapter}_adapter_test", :database => adapter) { }
-        (class << migration.adapter; self; end).included_modules.should include(expected_module)
+      expected_module_lambda = {
+        :sqlite   => lambda { SQL::Sqlite   },
+        :mysql    => lambda { SQL::Mysql    },
+        :postgres => lambda { SQL::Postgres }
+      }[adapter.to_sym]
+
+      expected_module = expected_module_lambda ? expected_module_lambda.call : nil
+
+      if expected_module
+        it "should extend with #{expected_module} when adapter is #{adapter}" do
+          migration = DataMapper::Migration.new(1, :"#{adapter}_adapter_test") { }
+          (class << migration.adapter; self; end).included_modules.should include(expected_module)
+        end
       end
     end
 
@@ -120,5 +138,7 @@ ADAPTERS.each do |adapter|
       end
 
     end
+
   end
+
 end
